@@ -1,12 +1,16 @@
-import streamlit as st
-import pandas as pd
-import matplotlib.pyplot as plt
-import numpy as np
-import os
-import cv2
-from PIL import Image
-import fire
-import random
+try:
+    import streamlit as st
+    import pandas as pd
+    import matplotlib.pyplot as plt
+    import numpy as np
+    import os
+    import cv2
+    from PIL import Image
+    import fire
+    import random
+except ModuleNotFoundError:
+    import os
+    os.system('pip install streamlit pandas fire matplotlib numpy PIL cv2')
 
 
 def process_one(image_type: str, image_name: str, percentage: float,
